==> jc-1.4.0.tar.gz: soot/toolkits/scalar/Pair.h <==
// public class soot.toolkits.scalar.Pair

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d665579dc9ea8690 soot_toolkits_scalar_Pair

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_scalar_Pair_H_
#define _JC_soot_toolkits_scalar_Pair_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_Pair$sub_refs	_jc_soot_toolkits_scalar_Pair$sub_refs;
typedef struct _jc_soot_toolkits_scalar_Pair$sub_nonrefs	_jc_soot_toolkits_scalar_Pair$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_Pair$refs	_jc_soot_toolkits_scalar_Pair$refs;
typedef struct _jc_soot_toolkits_scalar_Pair$nonrefs	_jc_soot_toolkits_scalar_Pair$nonrefs;
typedef struct _jc_soot_toolkits_scalar_Pair$object	_jc_soot_toolkits_scalar_Pair$object;

typedef const struct _jc_soot_toolkits_scalar_Pair$vmethods	_jc_soot_toolkits_scalar_Pair$vmethods;
typedef const struct _jc_soot_toolkits_scalar_Pair$vtable	_jc_soot_toolkits_scalar_Pair$vtable;
typedef const struct _jc_soot_toolkits_scalar_Pair$vtype	_jc_soot_toolkits_scalar_Pair$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_Pair$method$_init$1b34a4ef37055d19(_jc_env *, struct _jc_soot_toolkits_scalar_Pair$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern jboolean _jc_soot_toolkits_scalar_Pair$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_toolkits_scalar_Pair$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_toolkits_scalar_Pair$method$getO1$317304757089a5b3(_jc_env *, struct _jc_soot_toolkits_scalar_Pair$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_toolkits_scalar_Pair$method$getO2$e05c7d903a445d50(_jc_env *, struct _jc_soot_toolkits_scalar_Pair$object *);
extern jint _jc_soot_toolkits_scalar_Pair$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_toolkits_scalar_Pair$object *);
extern struct _jc_java_lang_String$object *_jc_soot_toolkits_scalar_Pair$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_toolkits_scalar_Pair$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_Pair$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_toolkits_scalar_Pair$method_info$getO1$317304757089a5b3;
extern _jc_method _jc_soot_toolkits_scalar_Pair$method_info$getO2$e05c7d903a445d50;
extern _jc_method _jc_soot_toolkits_scalar_Pair$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_toolkits_scalar_Pair$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_Pair$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_toolkits_scalar_Pair$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*getO1$317304757089a5b3)(_jc_env *, struct _jc_soot_toolkits_scalar_Pair$object *);
	struct _jc_java_lang_Object$object	*(*getO2$e05c7d903a445d50)(_jc_env *, struct _jc_soot_toolkits_scalar_Pair$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_toolkits_scalar_Pair$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_toolkits_scalar_Pair$object *);
};

// Vtable
struct _jc_soot_toolkits_scalar_Pair$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_Pair$vmethods	soot_toolkits_scalar_Pair;
};

// Vtype
struct _jc_soot_toolkits_scalar_Pair$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_Pair$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_Pair$sub_refs {
	struct _jc_java_lang_Object$object	*o1;
	struct _jc_java_lang_Object$object	*o2;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_Pair$refs {
    _jc_soot_toolkits_scalar_Pair$sub_refs	soot_toolkits_scalar_Pair;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_Pair$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_Pair$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_Pair$sub_nonrefs	soot_toolkits_scalar_Pair;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_Pair$object {
	_jc_soot_toolkits_scalar_Pair$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_Pair$vtype	*vtype;
	_jc_soot_toolkits_scalar_Pair$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_Pair$vtype _jc_soot_toolkits_scalar_Pair$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_Pair, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_Pair$class_object;

#endif	/* _JC_soot_toolkits_scalar_Pair_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/scalar/Pair.h <==
// public class soot.toolkits.scalar.Pair

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d665579dc9ea8690 soot_toolkits_scalar_Pair

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_scalar_Pair_H_
#define _JC_soot_toolkits_scalar_Pair_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_Pair$sub_refs	_jc_soot_toolkits_scalar_Pair$sub_refs;
typedef struct _jc_soot_toolkits_scalar_Pair$sub_nonrefs	_jc_soot_toolkits_scalar_Pair$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_Pair$refs	_jc_soot_toolkits_scalar_Pair$refs;
typedef struct _jc_soot_toolkits_scalar_Pair$nonrefs	_jc_soot_toolkits_scalar_Pair$nonrefs;
typedef struct _jc_soot_toolkits_scalar_Pair$object	_jc_soot_toolkits_scalar_Pair$object;

typedef const struct _jc_soot_toolkits_scalar_Pair$vmethods	_jc_soot_toolkits_scalar_Pair$vmethods;
typedef const struct _jc_soot_toolkits_scalar_Pair$vtable	_jc_soot_toolkits_scalar_Pair$vtable;
typedef const struct _jc_soot_toolkits_scalar_Pair$vtype	_jc_soot_toolkits_scalar_Pair$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_Pair$method$_init$1b34a4ef37055d19(_jc_env *, struct _jc_soot_toolkits_scalar_Pair$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_toolkits_scalar_Pair$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_toolkits_scalar_Pair$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_toolkits_scalar_Pair$method$getO1$317304757089a5b3(_jc_env *, struct _jc_soot_toolkits_scalar_Pair$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_toolkits_scalar_Pair$method$getO2$e05c7d903a445d50(_jc_env *, struct _jc_soot_toolkits_scalar_Pair$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_toolkits_scalar_Pair$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_toolkits_scalar_Pair$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_toolkits_scalar_Pair$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_toolkits_scalar_Pair$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_Pair$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_toolkits_scalar_Pair$method_info$getO1$317304757089a5b3;
extern _jc_method _jc_soot_toolkits_scalar_Pair$method_info$getO2$e05c7d903a445d50;
extern _jc_method _jc_soot_toolkits_scalar_Pair$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_toolkits_scalar_Pair$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_Pair$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_toolkits_scalar_Pair$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getO1$317304757089a5b3)(_jc_env *, struct _jc_soot_toolkits_scalar_Pair$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getO2$e05c7d903a445d50)(_jc_env *, struct _jc_soot_toolkits_scalar_Pair$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_toolkits_scalar_Pair$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_toolkits_scalar_Pair$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_toolkits_scalar_Pair$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_Pair$vmethods	soot_toolkits_scalar_Pair;
};

// Vtype
struct _jc_soot_toolkits_scalar_Pair$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_Pair$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_Pair$sub_refs {
	struct _jc_java_lang_Object$object	*o1;
	struct _jc_java_lang_Object$object	*o2;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_Pair$refs {
    _jc_soot_toolkits_scalar_Pair$sub_refs	soot_toolkits_scalar_Pair;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_Pair$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_Pair$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_Pair$sub_nonrefs	soot_toolkits_scalar_Pair;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_Pair$object {
	_jc_soot_toolkits_scalar_Pair$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_Pair$vtype	*vtype;
	_jc_soot_toolkits_scalar_Pair$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_Pair$vtype _jc_soot_toolkits_scalar_Pair$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_Pair, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_Pair$class_object;

#endif	/* _JC_soot_toolkits_scalar_Pair_H_ */
